
def load_variations(filename):
	f = open(filename)
	row = ""
	variations = []

	# read header
	while row != "######## VARIANT INDEX ########":
		row = f.readline().strip()
	f.readline()
	f.readline()

	# read content
	for row in f.readlines():
		data = row.split("\t")
		variations.append((data[0],data[2],data[4]))

	f.close()
	return variations


def consequence_stats(variations):
	cons_dict = {}
	gene_set = set()

	# compute counts
	for (gene, variation, consequence) in variations:
		gene_set.add(gene)
		if not consequence in cons_dict:
			cons_dict[consequence] = 1
		else:
			cons_dict[consequence] += 1

	# normalize counts
	for consequence in cons_dict.keys():
		cons_dict[consequence] /= len(gene_set)

	return cons_dict	

def variation_stats(variations):
	variation_dict = {}

	# compute counts
	for (_, variation, _) in variations:
		variation_residues = variation[2:5] + "-" + variation[-3:]
		if not variation_residues in variation_dict:
			variation_dict[variation_residues] = 1
		else:
			variation_dict[variation_residues] += 1			

	# normalize counts
	for variation in variation_dict:
		variation_dict[variation] /= len(variations)

	return variation_dict	

def print_stats(stats_dict):
	print("\n".join(["%s\t%.5f" %(k,v) for (k,v) in stats_dict.items()]))

variation_file = input("Variation file name: ")
variations = load_variations(variation_file)
print_stats(consequence_stats(variations))
print_stats(variation_stats(variations))